==> icinga2_2.6.3.orig.tar.gz: icinga2-2.6.3/lib/remote/messageorigin.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2017 Icinga Development Team (https://www.icinga.com/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef MESSAGEORIGIN_H
#define MESSAGEORIGIN_H

#include "remote/zone.hpp"
#include "remote/jsonrpcconnection.hpp"

namespace icinga
{

/**
 * @ingroup remote
 */
class I2_REMOTE_API MessageOrigin : public Object
{
public:
	DECLARE_PTR_TYPEDEFS(MessageOrigin);

	Zone::Ptr FromZone;
	JsonRpcConnection::Ptr FromClient;

	bool IsLocal(void) const;
};

}

#endif /* MESSAGEORIGIN_H */

==> icinga2-2.10.0.tar.gz: icinga2-2.10.0/lib/remote/messageorigin.hpp <==
/******************************************************************************
 * Icinga 2                                                                   *
 * Copyright (C) 2012-2018 Icinga Development Team (https://www.icinga.com/)  *
 *                                                                            *
 * This program is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU General Public License                *
 * as published by the Free Software Foundation; either version 2             *
 * of the License, or (at your option) any later version.                     *
 *                                                                            *
 * This program is distributed in the hope that it will be useful,            *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
 * GNU General Public License for more details.                               *
 *                                                                            *
 * You should have received a copy of the GNU General Public License          *
 * along with this program; if not, write to the Free Software Foundation     *
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.             *
 ******************************************************************************/

#ifndef MESSAGEORIGIN_H
#define MESSAGEORIGIN_H

#include "remote/zone.hpp"
#include "remote/jsonrpcconnection.hpp"

namespace icinga
{

/**
 * @ingroup remote
 */
class MessageOrigin final : public Object
{
public:
	DECLARE_PTR_TYPEDEFS(MessageOrigin);

	Zone::Ptr FromZone;
	JsonRpcConnection::Ptr FromClient;

	bool IsLocal() const;
};

}

#endif /* MESSAGEORIGIN_H */
